pub struct RemoteCache { /* private fields */ }Expand description
A remote cache that stores data via the btdt HTTP API.
Implementations
Sourceimpl RemoteCache
impl RemoteCache
Sourcepub fn new(
base_url: Url,
client: HttpClient,
token: UnverifiedBiscuit,
) -> Result<Self, RemoteCacheError>
pub fn new( base_url: Url, client: HttpClient, token: UnverifiedBiscuit, ) -> Result<Self, RemoteCacheError>
Creates a new remote cache with the given base URL, HTTP client, and authentication token.